// Overrides the built-in TextFX function to make it more flexible. Changes the printing from <span> to div. Removes "pt" from the size to make it fully customizable. Also adds an optional 'alignment' variable to allow you to change the alignment of the text, and an optional 'margin' variable to change the margin-left of the text (for a better centered typewriter effect).
var TextFX = new function() {
    var fxCount = 0;

    function addFx(text, font, color, size, alignment, margin) {
        fxCount++;
		if (isNaN(size)) {
			// isNaN will return true if not just a number. Assume size units already attached
			var style = "font-family:" + font + ";color:" + color + ";font-size:" + size;
        }
		else {
			// isNaN will return false if size is JUST a number. In which case, assume pt
			var style = "font-family:" + font + ";color:" + color + ";font-size:" + size + "pt";
		}
		if (typeof alignment !== 'undefined') {
		  style = style + ";text-align:" + alignment
		}
		if (typeof margin !== 'undefined') {
		  style = style + ";margin-left:" + margin
		}
		var html = "<div id=\"fx" + fxCount + "\" style=\"" + style + "\">" + text + " </div><br />";
        addText(html);
        return $("#fx" + fxCount);
    }

    this.Typewriter = function(text, speed, font, color, size, alignment, margin) {
        var el = addFx(text, font, color, size, alignment, margin);
        el.typewriter(speed);
    }

    this.Unscramble = function(text, speed, reveal, font, color, size, alignment, margin) {
        var el = addFx(text, font, color, size, alignment, margin);
        el.unscramble(speed, reveal);
    }
}